@@ -23,4 +23,4 @@
 
 from ._version import __version__
 
-from .workflows.mri.jobs import (RecoJob)
\ No newline at end of file
+from .workflows.mri import (RecoJob)
\ No newline at end of file
